@@ -1,6 +1,7 @@
 from json import loads
 from urllib.request import urlopen
 from functools import lru_cache
+#start doing error handleing here
 class User_Requests:
     """Makes the user requests to speedrun.com"""
     
@@ -72,4 +73,13 @@ class Game_Requests:
         return self.final_links
 
     def __init__(self, game):
-        self.game = game
\ No newline at end of file
+        self.game = game
+
+class Misc_Requests:
+    
+    @lru_cache
+    def region_request(self):
+        url = f'https://www.speedrun.com/api/v1/regions/{self.misc}'
+
+    def __init__(self, misc):
+        self.misc = misc
\ No newline at end of file
